Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3912)

Unified Diff: chrome/browser/extensions/api/record/record_api.cc

Issue 11747025: Run the JSON Schema Compiler's bundle compilation on JSON files. Previously it (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix ms release build Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/record/record_api.cc
diff --git a/chrome/browser/extensions/api/record/record_api.cc b/chrome/browser/extensions/api/record/record_api.cc
index ff60cb3327a86a44ad783e2f66725bbe9707c942..a16b75536623a7b8e563393d2cb5b89701b7890f 100644
--- a/chrome/browser/extensions/api/record/record_api.cc
+++ b/chrome/browser/extensions/api/record/record_api.cc
@@ -152,16 +152,16 @@ const ProcessStrategy &RunPageCyclerFunction::GetProcessStrategy() {
return *process_strategy_;
}
-// CaptureURLsFunction ------------------------------------------------
+// RecordCaptureURLsFunction ------------------------------------------------
-CaptureURLsFunction::CaptureURLsFunction()
+RecordCaptureURLsFunction::RecordCaptureURLsFunction()
: RunPageCyclerFunction(new ProductionProcessStrategy()) {}
-CaptureURLsFunction::CaptureURLsFunction(ProcessStrategy* strategy)
+RecordCaptureURLsFunction::RecordCaptureURLsFunction(ProcessStrategy* strategy)
: RunPageCyclerFunction(strategy) {}
// Fetch data for possible optional switch for an extension to load.
-bool CaptureURLsFunction::ParseJSParameters() {
+bool RecordCaptureURLsFunction::ParseJSParameters() {
scoped_ptr<record::CaptureURLs::Params> params(
record::CaptureURLs::Params::Create(*args_));
EXTENSION_FUNCTION_VALIDATE(params.get());
@@ -174,34 +174,34 @@ bool CaptureURLsFunction::ParseJSParameters() {
return true;
}
// CaptureURLsFunction adds "record-mode" to sub-browser call, and returns
// just the (possibly empty) error list.
-void CaptureURLsFunction::AddSwitches(CommandLine* line) {
+void RecordCaptureURLsFunction::AddSwitches(CommandLine* line) {
if (!line->HasSwitch(switches::kRecordMode))
line->AppendSwitch(switches::kRecordMode);
}
-void CaptureURLsFunction::Finish() {
+void RecordCaptureURLsFunction::Finish() {
results_ = record::CaptureURLs::Results::Create(errors_);
SendResponse(true);
}
-// ReplayURLsFunction ------------------------------------------------
+// RecordReplayURLsFunction ------------------------------------------------
-ReplayURLsFunction::ReplayURLsFunction()
+RecordReplayURLsFunction::RecordReplayURLsFunction()
: RunPageCyclerFunction(new ProductionProcessStrategy()),
run_time_ms_(0.0) {
}
-ReplayURLsFunction::ReplayURLsFunction(ProcessStrategy* strategy)
+RecordReplayURLsFunction::RecordReplayURLsFunction(ProcessStrategy* strategy)
: RunPageCyclerFunction(strategy), run_time_ms_(0.0) {
}
-ReplayURLsFunction::~ReplayURLsFunction() {}
+RecordReplayURLsFunction::~RecordReplayURLsFunction() {}
// Fetch data for possible optional switches for a repeat count and an
// extension to load.
-bool ReplayURLsFunction::ParseJSParameters() {
+bool RecordReplayURLsFunction::ParseJSParameters() {
scoped_ptr<record::ReplayURLs::Params> params(
record::ReplayURLs::Params::Create(*args_));
EXTENSION_FUNCTION_VALIDATE(params.get());
@@ -228,7 +228,7 @@ bool ReplayURLsFunction::ParseJSParameters() {
// plus temp file into which to place stats. (Can't do this in
// ParseJSParameters because file creation can't go on the UI thread.)
// Plus, initialize time to create run time statistic.
-void ReplayURLsFunction::AddSwitches(CommandLine* line) {
+void RecordReplayURLsFunction::AddSwitches(CommandLine* line) {
file_util::CreateTemporaryFile(&stats_file_path_);
if (!extension_path_.empty())
@@ -240,13 +240,13 @@ void ReplayURLsFunction::AddSwitches(CommandLine* line) {
}
// Read stats file, and get run time.
-void ReplayURLsFunction::ReadReplyFiles() {
+void RecordReplayURLsFunction::ReadReplyFiles() {
file_util::ReadFileToString(stats_file_path_, &stats_);
run_time_ms_ = (base::Time::NowFromSystemTime() - timer_).InMillisecondsF();
}
-void ReplayURLsFunction::Finish() {
+void RecordReplayURLsFunction::Finish() {
record::ReplayURLsResult result;
result.run_time = run_time_ms_;
« no previous file with comments | « chrome/browser/extensions/api/record/record_api.h ('k') | chrome/browser/extensions/api/record/record_api_test.cc » ('j') | no next file with comments »
@@ -174,34 +174,34 @@ bool CaptureURLsFunction::ParseJSParameters() {
return true;
}
-// CaptureURLsFunction adds "record-mode" to sub-browser call, and returns
+// RecordCaptureURLsFunction adds "record-mode" to sub-browser call, and returns
// just the (possibly empty) error list.

Powered by Google App Engine
This is Rietveld 408576698